OiRA

Help

1. Presentazione
2. Processo di VR
3. Identificazione + Valutazione
4. Misure di miglioramento
5. Report
6. Stato 0%

# Scaricare e stampare il report

Consigliamo di tenere sempre disponibile nella tua azienda una versione aggiornata e stampata del report.

Report

- Format: Rich Text Format (.rtf)
- Contains: all the information and input provided by you throughout the risk assessment process.

Programma di miglioramento

- Format: Office Open XML Workbook (.xlsx)
- Contains: main elements to effectively manage the risks at your workplace.

panoramica dei rischi

- Format: Portable Document Format (.pdf)
- Contains: an overview of the risks identified

Panoramica delle misure

- Format: Portable Document Format (.pdf)
- Contains: an overview of the measures to be implemented.

Scroll to top
Back

## report-download.html

Help

Standard search Advanced search

- Splash and Shine Cleaners Last saved 19 days ago based on EU Cleaning More
- Commercial Guardinng, Leicester Last saved 2 months ago based on Private Security EU More
- Private Security, Grafton Street Last saved 2 months ago based on Private Security EU More
- Office operations in times of COVID-19 Last saved 4 months ago based on COVID-19 More